.. image:: https://travis-ci.org/vinayinvicible/django-route.svg
    :target: https://travis-ci.org/vinayinvicible/django-route

.. image:: https://codecov.io/gh/vinayinvicible/django-route/coverage.svg?branch=master
    :target: https://codecov.io/gh/vinayinvicible/django-route

django-route
============

Conditional url routing for django

Installation
------------

pip install django-route

Contributing
------------

1. Fork it!
2. Create your feature branch: `git checkout -b my-new-feature`
3. Commit your changes: `git commit -am 'Add some feature'`
4. Push to the branch: `git push origin my-new-feature`
5. Submit a pull request :D

Usage
-----

1. Create a router for the url
2. Add destination url
3. Provide the action (301/302/proxy)
4. Describe the condition in templating language

License
-------

This project is licensed under the MIT License - see the LICENSE_ file for details

.. _LICENSE: https://github.com/vinayinvicible/django-route/blob/master/LICENSE
